==> aria2_0.12.1.orig.tar.gz: aria2-0.12.1/src/BtNotInterestedMessage.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_BT_NOT_INTERESTED_MESSAGE_H_
#define _D_BT_NOT_INTERESTED_MESSAGE_H_

#include "SimpleBtMessage.h"

class BtNotInterestedMessage;

typedef SharedHandle<BtNotInterestedMessage> BtNotInterestedMessageHandle;

class BtNotInterestedMessage : public SimpleBtMessage {
private:
  unsigned char* msg;
  
  static int32_t MESSAGE_LENGTH;
public:
  BtNotInterestedMessage():msg(0) {}

  virtual ~BtNotInterestedMessage() {
    delete [] msg;
  }

  static const int8_t ID = 3;

  static BtNotInterestedMessageHandle create(const unsigned char* data, int32_t dataLength);

  virtual int8_t getId() { return ID; }

  virtual void doReceivedAction();

  virtual const unsigned char* getMessage();

  virtual int32_t getMessageLength();

  virtual string toString() const;

  virtual bool sendPredicate() const;

  virtual void onSendComplete();
};

#endif // _D_BT_NOT_INTERESTED_MESSAGE_H_

==> aria2_1.1.2.orig.tar.gz: aria2-1.1.2/src/BtNotInterestedMessage.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_BT_NOT_INTERESTED_MESSAGE_H_
#define _D_BT_NOT_INTERESTED_MESSAGE_H_

#include "SimpleBtMessage.h"

namespace aria2 {

class PeerStorage;
class BtNotInterestedMessage;

typedef SharedHandle<BtNotInterestedMessage> BtNotInterestedMessageHandle;

class BtNotInterestedMessage : public SimpleBtMessage {
private:
  unsigned char* msg;
  
  SharedHandle<PeerStorage> _peerStorage;

  static size_t MESSAGE_LENGTH;
public:
  BtNotInterestedMessage():msg(0) {}

  virtual ~BtNotInterestedMessage() {
    delete [] msg;
  }

  static const uint8_t ID = 3;

  static BtNotInterestedMessageHandle create(const unsigned char* data, size_t dataLength);

  virtual uint8_t getId() { return ID; }

  virtual void doReceivedAction();

  virtual const unsigned char* getMessage();

  virtual size_t getMessageLength();

  virtual std::string toString() const;

  virtual bool sendPredicate() const;

  virtual void onSendComplete();

  void setPeerStorage(const SharedHandle<PeerStorage>& peerStorage);
};

} // namespace aria2

#endif // _D_BT_NOT_INTERESTED_MESSAGE_H_
